@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -24,7 +24,7 @@
 using namespace KChart;
 
 
-class StockDiagram::Private::ThreeDPainter
+class Q_DECL_HIDDEN StockDiagram::Private::ThreeDPainter
 {
 public:
     struct ThreeDProperties {
