@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -27,7 +27,7 @@
 
 namespace KChart {
 
-class StockDiagram::Private : public AbstractCartesianDiagram::Private
+class Q_DECL_HIDDEN StockDiagram::Private : public AbstractCartesianDiagram::Private
 {
     friend class StockDiagram;
 
