@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -94,7 +94,7 @@ namespace KChart {
  */
     class AttributesModel;
 
-    class KChart::AbstractDiagram::Private
+    class Q_DECL_HIDDEN KChart::AbstractDiagram::Private
     {
         friend class AbstractDiagram;
     public:
