@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -164,19 +164,19 @@ public:
     // the Legends/Advanced example. It will not work well in various ways - won't get enough space and look
     // very broken, will inhibit resizing the window etc.
 
-    QSize sizeHint() const
+    QSize sizeHint() const Q_DECL_OVERRIDE
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         return w->sizeHint();
     }
 
-    QSize minimumSize() const
+    QSize minimumSize() const Q_DECL_OVERRIDE
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         return w->minimumSize();
     }
 
-    QSize maximumSize() const
+    QSize maximumSize() const Q_DECL_OVERRIDE
     {
         // Not just passing on w->maximumSize() fixes that the size policy of Legend is disregarded, making
         // Legend take all available space, which makes both the Legend internal layout and the overall
@@ -197,7 +197,7 @@ public:
         return ret;
     }
 
-    Qt::Orientations expandingDirections() const
+    Qt::Orientations expandingDirections() const Q_DECL_OVERRIDE
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         if ( isEmpty() ) {
@@ -207,19 +207,19 @@ public:
         return e;
     }
 
-    void setGeometry(const QRect &g)
+    void setGeometry(const QRect &g) Q_DECL_OVERRIDE
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         w->setGeometry(g);
     }
 
-    QRect geometry() const
+    QRect geometry() const Q_DECL_OVERRIDE
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         return w->geometry();
     }
 
-    bool hasHeightForWidth() const
+    bool hasHeightForWidth() const Q_DECL_OVERRIDE
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         bool ret = !isEmpty() &&
@@ -227,14 +227,14 @@ public:
         return ret;
     }
 
-    int heightForWidth( int width ) const
+    int heightForWidth( int width ) const Q_DECL_OVERRIDE
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         int ret = w->heightForWidth( width );
         return ret;
     }
 
-    bool isEmpty() const {
+    bool isEmpty() const Q_DECL_OVERRIDE {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         // legend->hide() should indeed hide the legend,
         // but a legend in a chart that hasn't been shown yet isn't hidden
