@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -181,6 +181,10 @@ template class Q_DECL_IMPORT QVector<QPointF>;
 
 #include <Qt>
 
+/**
+  \namespace KChart
+  \brief Global namespace
+  */
 namespace KChart {
 
 enum DisplayRoles {
