@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "kganttgraphicsscene.h"
@@ -24,11 +24,8 @@
 #include "kganttconstraintgraphicsitem.h"
 #include "kganttitemdelegate.h"
 #include "kganttabstractrowcontroller.h"
-#include "kganttabstractgrid.h"
 #include "kganttdatetimegrid.h"
 #include "kganttsummaryhandlingproxymodel.h"
-#include "kganttgraphicsview.h"
-#include "kganttprintingcontext.h"
 
 #include <QApplication>
 #include <QGraphicsSceneHelpEvent>
@@ -53,30 +50,28 @@
 #endif
 #endif
 
-
+/*!\class KGantt::GraphicsScene
+ * \internal
+ */
 
 using namespace KGantt;
 
 GraphicsScene::Private::Private( GraphicsScene* _q )
     : q( _q ),
-      dragSource( nullptr ),
+      dragSource( 0 ),
       itemDelegate( new ItemDelegate( _q ) ),
-      rowController( nullptr ),
+      rowController( 0 ),
+      grid( &default_grid ),
       readOnly( false ),
       isPrinting( false ),
       drawColumnLabels( true ),
       labelsWidth( 0.0 ),
       summaryHandlingModel( new SummaryHandlingProxyModel( _q ) ),
-      selectionModel( nullptr )
+      selectionModel( 0 )
 {
     default_grid.setStartDateTime( QDateTime::currentDateTime().addDays( -1 ) );
 }
 
-GraphicsScene::Private::~Private()
-{
-    delete grid;
-}
-
 void GraphicsScene::Private::clearConstraintItems()
 {
     for(ConstraintGraphicsItem *citem : constraintItems) {
@@ -95,8 +90,8 @@ void GraphicsScene::Private::resetConstraintItems()
 {
     clearConstraintItems();
     if ( constraintModel.isNull() ) return;
-    const QList<Constraint> clst = constraintModel->constraints();
-    for ( const Constraint& c : clst ) {
+    QList<Constraint> clst = constraintModel->constraints();
+    Q_FOREACH( const Constraint& c, clst ) {
         createConstraintItem( c );
     }
     q->updateItems();
@@ -122,15 +117,15 @@ void GraphicsScene::Private::createConstraintItem( const Constraint& c )
 void GraphicsScene::Private::deleteConstraintItem( ConstraintGraphicsItem *citem )
 {
     //qDebug()<<"GraphicsScene::Private::deleteConstraintItem citem="<<citem;
-    if ( citem == nullptr ) {
+    if ( citem == 0 ) {
         return;
     }
     Constraint c = citem->constraint();
-    GraphicsItem* item = items.value( summaryHandlingModel->mapFromSource( c.startIndex() ), nullptr );
+    GraphicsItem* item = items.value( summaryHandlingModel->mapFromSource( c.startIndex() ), 0 );
     if ( item ) {
         item->removeStartConstraint( citem );
     }
-    item = items.value( summaryHandlingModel->mapFromSource( c.endIndex() ), nullptr );
+    item = items.value( summaryHandlingModel->mapFromSource( c.endIndex() ), 0 );
     if ( item ) {
         item->removeEndConstraint( citem );
     }
@@ -145,7 +140,7 @@ void GraphicsScene::Private::deleteConstraintItem( const Constraint& c )
 
 ConstraintGraphicsItem* GraphicsScene::Private::findConstraintItem( const Constraint& c ) const
 {
-    GraphicsItem* item = items.value( summaryHandlingModel->mapFromSource( c.startIndex() ), nullptr );
+    GraphicsItem* item = items.value( summaryHandlingModel->mapFromSource( c.startIndex() ), 0 );
     if ( item ) {
         const QList<ConstraintGraphicsItem*> clst = item->startConstraints();
         QList<ConstraintGraphicsItem*>::const_iterator it = clst.begin();
@@ -157,7 +152,7 @@ ConstraintGraphicsItem* GraphicsScene::Private::findConstraintItem( const Constr
             return *it;
         }
     }
-    item = items.value( summaryHandlingModel->mapFromSource( c.endIndex() ), nullptr );
+    item = items.value( summaryHandlingModel->mapFromSource( c.endIndex() ), 0 );
     if ( item ) {
         const QList<ConstraintGraphicsItem*> clst = item->endConstraints();
         QList<ConstraintGraphicsItem*>::const_iterator it = clst.begin();
@@ -169,7 +164,7 @@ ConstraintGraphicsItem* GraphicsScene::Private::findConstraintItem( const Constr
             return *it;
         }
     }
-    return nullptr;
+    return 0;
 }
 
 // NOTE: we might get here after indexes are invalidated, so cannot do any controlled cleanup
@@ -184,22 +179,6 @@ void GraphicsScene::Private::clearItems()
     clearConstraintItems();
 }
 
-AbstractGrid *GraphicsScene::Private::getGrid()
-{
-    if (grid.isNull()) {
-        return static_cast<AbstractGrid*>(&default_grid);
-    }
-    return grid.data();
-}
-
-const AbstractGrid *GraphicsScene::Private::getGrid() const
-{
-    if (grid.isNull()) {
-        return static_cast<const AbstractGrid*>(&default_grid);
-    }
-    return grid.data();
-}
-
 GraphicsScene::GraphicsScene( QObject* parent )
     : QGraphicsScene( parent ), _d( new Private( this ) )
 {
@@ -218,7 +197,7 @@ void GraphicsScene::init()
 {
     setItemIndexMethod( QGraphicsScene::NoIndex );
     setConstraintModel( new ConstraintModel( this ) );
-    connect( d->getGrid(), SIGNAL(gridChanged()), this, SLOT(slotGridChanged()) );
+    connect( d->grid, SIGNAL( gridChanged() ), this, SLOT( slotGridChanged() ) );
 }
 
 /* NOTE: The delegate should really be a property
@@ -247,7 +226,7 @@ void GraphicsScene::setModel( QAbstractItemModel* model )
 {
     assert(!d->summaryHandlingModel.isNull());
     d->summaryHandlingModel->setSourceModel(model);
-    d->getGrid()->setModel( d->summaryHandlingModel );
+    d->grid->setModel( d->summaryHandlingModel );
     setSelectionModel( new QItemSelectionModel( model, this ) );
 }
 
@@ -264,12 +243,12 @@ void GraphicsScene::setSummaryHandlingModel( QAbstractProxyModel* proxyModel )
 
 void GraphicsScene::setRootIndex( const QModelIndex& idx )
 {
-    d->getGrid()->setRootIndex( idx );
+    d->grid->setRootIndex( idx );
 }
 
 QModelIndex GraphicsScene::rootIndex() const
 {
-    return d->getGrid()->rootIndex();
+    return d->grid->rootIndex();
 }
 
 ConstraintModel* GraphicsScene::constraintModel() const
@@ -285,25 +264,17 @@ void GraphicsScene::setConstraintModel( ConstraintModel* cm )
     }
     d->constraintModel = cm;
 
-    connect( cm, SIGNAL(constraintAdded(KGantt::Constraint)),
-             this, SLOT(slotConstraintAdded(KGantt::Constraint)) );
-    connect( cm, SIGNAL(constraintRemoved(KGantt::Constraint)),
-             this, SLOT(slotConstraintRemoved(KGantt::Constraint)) );
+    connect( cm, SIGNAL( constraintAdded( const KGantt::Constraint& ) ),
+             this, SLOT( slotConstraintAdded( const KGantt::Constraint& ) ) );
+    connect( cm, SIGNAL( constraintRemoved( const KGantt::Constraint& ) ),
+             this, SLOT( slotConstraintRemoved( const KGantt::Constraint& ) ) );
     d->resetConstraintItems();
 }
 
 void GraphicsScene::setSelectionModel( QItemSelectionModel* smodel )
 {
-    if (d->selectionModel) {
-        d->selectionModel->disconnect( this );
-    }
     d->selectionModel = smodel;
-    if (smodel) {
-        connect(d->selectionModel, SIGNAL(modelChanged(QAbstractItemModel*)),
-                this, SLOT(selectionModelChanged(QAbstractItemModel*)));
-        connect( smodel, SIGNAL(selectionChanged(const QItemSelection&,const QItemSelection&)),
-                 this, SLOT(slotSelectionChanged(const QItemSelection&,const QItemSelection&)) );
-    }
+    // TODO: update selection from model and connect signals
 }
 
 QItemSelectionModel* GraphicsScene::selectionModel() const
@@ -321,44 +292,25 @@ AbstractRowController* GraphicsScene::rowController() const
     return d->rowController;
 }
 
-AbstractGrid *GraphicsScene::takeGrid()
-{
-    AbstractGrid *grid = d->grid;
-    grid->disconnect( this );
-    d->grid = nullptr;
-    if (grid) {
-        // revert to the default_grid
-        connect( &d->default_grid, SIGNAL(gridChanged()), this, SLOT(slotGridChanged()) );
-    }
-    return grid;
-}
-
 void GraphicsScene::setGrid( AbstractGrid* grid )
 {
-    QAbstractItemModel* model = nullptr;
-    if ( d->getGrid() ) {
-        d->getGrid()->disconnect( this );
-        model = d->getGrid()->model();
+    QAbstractItemModel* model = 0;
+    if ( grid == 0 ) grid = &d->default_grid;
+    if ( d->grid ) {
+        d->grid->disconnect( this );
+        model = d->grid->model();
     }
-    delete d->grid;
     d->grid = grid;
-    connect( d->getGrid(), SIGNAL(gridChanged()), this, SLOT(slotGridChanged()) );
-    d->getGrid()->setModel( model );
+    connect( d->grid, SIGNAL( gridChanged() ), this, SLOT( slotGridChanged() ) );
+    d->grid->setModel( model );
     slotGridChanged();
 }
 
-// Returns the explicitly set grid
 AbstractGrid* GraphicsScene::grid() const
 {
     return d->grid;
 }
 
-// May also return the default_grid if a grid has not been set
-const AbstractGrid *GraphicsScene::getGrid() const
-{
-    return d->getGrid();
-}
-
 void GraphicsScene::setReadOnly( bool ro )
 {
     d->readOnly = ro;
@@ -387,7 +339,10 @@ QModelIndex GraphicsScene::mainIndex( const QModelIndex& idx )
 #endif
 }
 
-
+/*! Returns the index pointing to the last column
+ * in the same row as idx. This can be thought of
+ * as in "inverse" of mainIndex()
+ */
 QModelIndex GraphicsScene::dataIndex( const QModelIndex& idx )
 {
 #if 0
@@ -402,19 +357,23 @@ QModelIndex GraphicsScene::dataIndex( const QModelIndex& idx )
 #endif
 }
 
-
+/*! Creates a new item of type type.
+ * TODO: If the user should be allowed to override
+ * this in any way, it needs to be in View!
+ */
 GraphicsItem* GraphicsScene::createItem( ItemType type ) const
 {
 #if 0
-    TODO For 3.0
-    assert(views().count() == 1);
-    GraphicsView *v = qobject_cast<GraphicsView*>(views().first());
-    assert(v);
-    return v->createItem(type);
-#else
-    Q_UNUSED(type)
-    return new GraphicsItem;
+    switch ( type ) {
+    case TypeEvent:   return 0;
+    case TypeTask:    return new TaskItem;
+    case TypeSummary: return new SummaryItem;
+    default:          return 0;
+    }
 #endif
+    //qDebug() << "GraphicsScene::createItem("<<type<<")";
+    Q_UNUSED( type );
+    return new GraphicsItem;
 }
 
 void GraphicsScene::Private::recursiveUpdateMultiItem( const Span& span, const QModelIndex& idx )
@@ -430,7 +389,7 @@ void GraphicsScene::Private::recursiveUpdateMultiItem( const Span& span, const Q
     item->updateItem( span, idx );
     QModelIndex child;
     int cr = 0;
-    while ( ( child = summaryHandlingModel->index( cr, 0, idx ) ).isValid() ) {
+    while ( ( child = idx.child( cr, 0 ) ).isValid() ) {
         recursiveUpdateMultiItem( span, child );
         ++cr;
     }
@@ -492,11 +451,11 @@ void GraphicsScene::insertItem( const QPersistentModelIndex& idx, GraphicsItem*
         // Create items for constraints
         const QModelIndex sidx = summaryHandlingModel()->mapToSource( idx );
         const QList<Constraint> clst = d->constraintModel->constraintsForIndex( sidx );
-        for ( const Constraint& c :  clst ) {
+        Q_FOREACH( const Constraint& c,  clst ) {
             QModelIndex other_idx;
             if ( c.startIndex() == sidx ) {
                 other_idx = c.endIndex();
-                GraphicsItem* other_item = d->items.value(summaryHandlingModel()->mapFromSource( other_idx ),nullptr);
+                GraphicsItem* other_item = d->items.value(summaryHandlingModel()->mapFromSource( other_idx ),0);
                 if ( !other_item ) continue;
                 ConstraintGraphicsItem* citem = new ConstraintGraphicsItem( c );
                 item->addStartConstraint( citem );
@@ -505,7 +464,7 @@ void GraphicsScene::insertItem( const QPersistentModelIndex& idx, GraphicsItem*
                 addItem( citem );
             } else if ( c.endIndex() == sidx ) {
                 other_idx = c.startIndex();
-                GraphicsItem* other_item = d->items.value(summaryHandlingModel()->mapFromSource( other_idx ),nullptr);
+                GraphicsItem* other_item = d->items.value(summaryHandlingModel()->mapFromSource( other_idx ),0);
                 if ( !other_item ) continue;
                 ConstraintGraphicsItem* citem = new ConstraintGraphicsItem( c );
                 other_item->addStartConstraint( citem );
@@ -533,17 +492,9 @@ void GraphicsScene::removeItem( const QModelIndex& idx )
         d->items.erase( it );
         {
             // Remove any constraintitems attached
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-            // TODO remove when we depend on 5.14+
             const QSet<ConstraintGraphicsItem*> clst = QSet<ConstraintGraphicsItem*>::fromList( item->startConstraints() ) +
                                                        QSet<ConstraintGraphicsItem*>::fromList( item->endConstraints() );
-#else
-            const QList<ConstraintGraphicsItem*> lst1 = item->startConstraints();
-            const QList<ConstraintGraphicsItem*> lst2 = item->endConstraints();
-            const QSet<ConstraintGraphicsItem*> clst = QSet<ConstraintGraphicsItem*>( lst1.begin(), lst1.end() ) +
-                                                       QSet<ConstraintGraphicsItem*>( lst2.begin(), lst2.end() );
-#endif
-            for ( ConstraintGraphicsItem* citem : clst ) {
+            Q_FOREACH( ConstraintGraphicsItem* citem, clst ) {
                 d->deleteConstraintItem( citem );
             }
         }
@@ -554,18 +505,18 @@ void GraphicsScene::removeItem( const QModelIndex& idx )
 
 GraphicsItem* GraphicsScene::findItem( const QModelIndex& idx ) const
 {
-    if ( !idx.isValid() ) return nullptr;
+    if ( !idx.isValid() ) return 0;
     assert( idx.model() == summaryHandlingModel() );
     QHash<QPersistentModelIndex,GraphicsItem*>::const_iterator it = d->items.find( idx );
-    return ( it != d->items.end() )?*it:nullptr;
+    return ( it != d->items.end() )?*it:0;
 }
 
 GraphicsItem* GraphicsScene::findItem( const QPersistentModelIndex& idx ) const
 {
-    if ( !idx.isValid() ) return nullptr;
+    if ( !idx.isValid() ) return 0;
     assert( idx.model() == summaryHandlingModel() );
     QHash<QPersistentModelIndex,GraphicsItem*>::const_iterator it = d->items.find( idx );
-    return ( it != d->items.end() )?*it:nullptr;
+    return ( it != d->items.end() )?*it:0;
 }
 
 void GraphicsScene::clearItems()
@@ -591,7 +542,7 @@ void GraphicsScene::deleteSubtree( const QModelIndex& _idx )
     const QModelIndex parent( idx.parent() );
     const int colcount = idx.model()->columnCount( parent );
     {for ( int i = 0; i < colcount; ++i ) {
-        removeItem( summaryHandlingModel()->index(idx.row(), i, parent ) );
+        removeItem( parent.child( idx.row(), i ) );
     }}
     const int rowcount = summaryHandlingModel()->rowCount( _idx );
     {for ( int i = 0; i < rowcount; ++i ) {
@@ -619,29 +570,7 @@ void GraphicsScene::slotGridChanged()
 {
     updateItems();
     update();
-    Q_EMIT gridChanged();
-}
-
-void GraphicsScene::selectionModelChanged(QAbstractItemModel *model)
-{
-    Q_UNUSED(model)
-}
-
-void GraphicsScene::slotSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
-{
-    for (const QModelIndex &idx : deselected.indexes()) {
-        GraphicsItem *item = findItem(idx.model() == d->summaryHandlingModel ? idx : d->summaryHandlingModel->mapFromSource(idx));
-        if (item) {
-            item->setSelected(false);
-        }
-    }
-    for (const QModelIndex &idx : selected.indexes()) {
-        GraphicsItem *item = findItem(idx.model() == d->summaryHandlingModel ? idx : d->summaryHandlingModel->mapFromSource(idx));
-        if (item) {
-            item->setSelected(true);
-        }
-    }
-    update();
+    emit gridChanged();
 }
 
 void GraphicsScene::helpEvent( QGraphicsSceneHelpEvent *helpEvent )
@@ -666,7 +595,7 @@ void GraphicsScene::drawBackground( QPainter* painter, const QRectF& _rect )
         QRectF headerRect( scn.topLeft()+QPointF( d->labelsWidth, 0 ),
                            QSizeF( scn.width()-d->labelsWidth, d->rowController->headerHeight() ));
 
-        d->getGrid()->paintHeader( painter, headerRect, rect, 0, nullptr );
+        d->grid->paintHeader( painter, headerRect, rect, 0, 0 );
 
 #if 0
         /* We have to blank out the part of the header that is invisible during
@@ -679,49 +608,40 @@ void GraphicsScene::drawBackground( QPainter* painter, const QRectF& _rect )
         opt.text = QLatin1String("");
         opt.textAlignment = Qt::AlignCenter;
         style()->drawControl(QStyle::CE_Header, &opt, painter, 0);
-#endif
-
+#endif        
+        
         scn.setTop( headerRect.bottom() );
         scn.setLeft( headerRect.left() );
         rect = rect.intersected( scn );
     }
-    d->getGrid()->paintGrid( painter, scn, rect, d->rowController );
+    d->grid->paintGrid( painter, scn, rect, d->rowController );
 
-    d->getGrid()->drawBackground(painter, rect);
+    d->grid->drawBackground(painter, rect);
 }
 
 void GraphicsScene::drawForeground( QPainter* painter, const QRectF& rect )
 {
-    d->getGrid()->drawForeground(painter, rect);
+    d->grid->drawForeground(painter, rect);
 }
 
 void GraphicsScene::itemEntered( const QModelIndex& idx )
 {
-    Q_EMIT entered( idx );
+    emit entered( idx );
 }
 
-void GraphicsScene::itemPressed( const QModelIndex& idx, QGraphicsSceneMouseEvent *event )
+void GraphicsScene::itemPressed( const QModelIndex& idx )
 {
-    if (event->button() == Qt::LeftButton) {
-        QItemSelectionModel::SelectionFlags flags;
-        if (event->modifiers() & Qt::ControlModifier) {
-            flags |= QItemSelectionModel::Toggle;
-        } else {
-            flags |= QItemSelectionModel::ClearAndSelect;
-        }
-        d->selectionModel->select(d->summaryHandlingModel->mapToSource(idx), flags);
-    }
-    Q_EMIT pressed( idx );
+    emit pressed( idx );
 }
 
 void GraphicsScene::itemClicked( const QModelIndex& idx )
 {
-    Q_EMIT clicked( idx );
+    emit clicked( idx );
 }
 
 void GraphicsScene::itemDoubleClicked( const QModelIndex& idx )
 {
-    Q_EMIT qrealClicked( idx );
+    emit qrealClicked( idx );
 }
 
 void GraphicsScene::setDragSource( GraphicsItem* item )
@@ -734,7 +654,14 @@ GraphicsItem* GraphicsScene::dragSource() const
     return d->dragSource;
 }
 
-
+/*! Print the Gantt chart using \a printer. If \a drawRowLabels
+ * is true (the default), each row will have it's label printed
+ * on the left side. If \a drawColumnLabels is true (the
+ * default), each column will have it's label printed at the
+ * top side.
+ *
+ * This version of print() will print multiple pages.
+ */
 void GraphicsScene::print( QPrinter* printer, bool drawRowLabels, bool drawColumnLabels )
 {
 #ifndef HAVE_PRINTER
@@ -747,7 +674,18 @@ void GraphicsScene::print( QPrinter* printer, bool drawRowLabels, bool drawColum
 #endif
 }
 
-
+/*! Print part of the Gantt chart from \a start to \a end using \a printer.
+ * If \a drawRowLabels is true (the default), each row will have it's
+ * label printed on the left side. If \a drawColumnLabels is true (the
+ * default), each column will have it's label printed at the
+ * top side.
+ *
+ * This version of print() will print multiple pages.
+ *
+ * To print a certain range of a chart with a DateTimeGrid, use
+ * qreal DateTimeGrid::mapFromDateTime( const QDateTime& dt) const
+ * to figure out the values for \a start and \a end.
+ */
 void GraphicsScene::print( QPrinter* printer, qreal start, qreal end, bool drawRowLabels, bool drawColumnLabels )
 {
 #ifndef HAVE_PRINTER
@@ -762,7 +700,12 @@ void GraphicsScene::print( QPrinter* printer, qreal start, qreal end, bool drawR
 #endif
 }
 
-
+/*! Render the GanttView inside the rectangle \a target using the painter \a painter.
+ * If \a drawRowLabels is true (the default), each row will have it's
+ * label printed on the left side. If \a drawColumnLabels is true (the
+ * default), each column will have it's label printed at the
+ * top side.
+ */
 void GraphicsScene::print( QPainter* painter, const QRectF& _targetRect, bool drawRowLabels, bool drawColumnLabels )
 {
     QRectF targetRect( _targetRect );
@@ -770,10 +713,19 @@ void GraphicsScene::print( QPainter* painter, const QRectF& _targetRect, bool dr
         targetRect = sceneRect();
     }
 
-    doPrint( painter, targetRect, sceneRect().left(), sceneRect().right(), nullptr, drawRowLabels, drawColumnLabels );
+    doPrint( painter, targetRect, sceneRect().left(), sceneRect().right(), 0, drawRowLabels, drawColumnLabels );
 }
 
-
+/*! Render the GanttView inside the rectangle \a target using the painter \a painter.
+ * If \a drawRowLabels is true (the default), each row will have it's
+ * label printed on the left side. If \a drawColumnLabels is true (the
+ * default), each column will have it's label printed at the
+ * top side.
+ *
+ * To print a certain range of a chart with a DateTimeGrid, use
+ * qreal DateTimeGrid::mapFromDateTime( const QDateTime& dt) const
+ * to figure out the values for \a start and \a end.
+ */
 void GraphicsScene::print( QPainter* painter, qreal start, qreal end,
                            const QRectF& _targetRect, bool drawRowLabels, bool drawColumnLabels )
 {
@@ -782,55 +734,19 @@ void GraphicsScene::print( QPainter* painter, qreal start, qreal end,
         targetRect = sceneRect();
     }
 
-    doPrint( painter, targetRect, start, end, nullptr, drawRowLabels, drawColumnLabels );
-}
-
-void GraphicsScene::printDiagram( QPrinter *printer, const PrintingContext &context )
-{
-#ifndef HAVE_PRINTER
-    Q_UNUSED( printer );
-    Q_UNUSED( context );
-#else
-    PrintingContext ctx( context );
-    if (ctx.sceneRect().isNull()) {
-        ctx.setSceneRect(sceneRect());
-    }
-    QRectF targetRect = printer->pageRect( QPrinter::DevicePixel );
-    if ( printer->fullPage() ) {
-        // Handle margins
-        QPageLayout pl = printer->pageLayout();
-        targetRect = targetRect.marginsRemoved( pl.marginsPixels( printer->resolution() ) );
-    }
-    QPainter painter( printer );
-    doPrintScene( printer, &painter, targetRect, ctx );
-#endif
+    doPrint( painter, targetRect, start, end, 0, drawRowLabels, drawColumnLabels );
 }
 
+/*!\internal
+ */
 void GraphicsScene::doPrint( QPainter* painter, const QRectF& targetRect,
                              qreal start, qreal end,
                              QPrinter* printer, bool drawRowLabels, bool drawColumnLabels )
 {
     assert( painter );
-    PrintingContext ctx;
-    ctx.setFitting(PrintingContext::FitPageHeight); // keep old behavior (?)
-    ctx.setDrawRowLabels( drawRowLabels );
-    ctx.setDrawColumnLabels( drawColumnLabels );
-    ctx.setSceneRect( sceneRect() );
-    ctx.setLeft( start );
-    ctx.setRight( end );
-    doPrintScene( printer, painter, targetRect, ctx );
-}
-
-void GraphicsScene::doPrintScene( QPrinter *printer, QPainter *painter, const QRectF &targetRect, const PrintingContext &context )
-{
-    assert( painter );
-
-    bool b = blockSignals( true );
-
     d->isPrinting = true;
-    d->drawColumnLabels = context.drawColumnLabels();
+    d->drawColumnLabels = drawColumnLabels;
     d->labelsWidth = 0.0;
-
     QFont sceneFont( font() );
 #ifdef HAVE_PRINTER
     if ( printer ) {
@@ -851,26 +767,22 @@ void GraphicsScene::doPrintScene( QPrinter *printer, QPainter *painter, const QR
 
     const QRectF oldScnRect( sceneRect() );
     QRectF scnRect( oldScnRect );
-    QRectF sceneHeaderRect;
-    QRectF labelsHeaderRect;
-    QRectF labelsRect;
+    scnRect.setLeft( start );
+    scnRect.setRight( end );
+    bool b = blockSignals( true );
 
     /* column labels */
-    qreal headerHeight = 0.0;
-    if ( context.drawColumnLabels() ) {
-        headerHeight = d->rowController->headerHeight();
-        sceneHeaderRect = context.sceneRect();
-        sceneHeaderRect.setLeft( context.left() );
-        sceneHeaderRect.setTop( -headerHeight );
-        sceneHeaderRect.setHeight( headerHeight );
-        scnRect.setTop(scnRect.top() - headerHeight);
+    if ( d->drawColumnLabels ) {
+        QRectF headerRect( scnRect );
+        headerRect.setHeight( - d->rowController->headerHeight() );
+        scnRect.setTop(scnRect.top() - d->rowController->headerHeight());
     }
 
     /* row labels */
     QVector<QGraphicsTextItem*> textLabels;
-    if ( context.drawRowLabels() ) {
+    if ( drawRowLabels ) {
         qreal textWidth = 0.;
-        qreal charWidth = QFontMetricsF(sceneFont).boundingRect( QString::fromLatin1( "X" ) ).width();
+        qreal charWidth = QFontMetricsF(sceneFont).width( QString::fromLatin1( "X" ) );
         QModelIndex sidx = summaryHandlingModel()->mapToSource( summaryHandlingModel()->index( 0, 0, rootIndex()) );
         do {
             QModelIndex idx = summaryHandlingModel()->mapFromSource( sidx );
@@ -879,168 +791,46 @@ void GraphicsScene::doPrintScene( QPrinter *printer, QPainter *painter, const QR
             QGraphicsTextItem* item = new QGraphicsTextItem( txt );
             addItem( item );
             textLabels << item;
-            item->setTextWidth( QFontMetricsF(sceneFont).boundingRect( txt ).width() + charWidth );
+            item->setTextWidth( QFontMetricsF(sceneFont).width( txt ) + charWidth );
             textWidth = qMax( item->textWidth(), textWidth );
             item->setPos( 0, rg.start() );
         } while ( ( sidx = rowController()->indexBelow( sidx ) ).isValid() );
-        d->labelsWidth = textWidth;
-        scnRect.setLeft( scnRect.left() - textWidth );
-        for( QGraphicsTextItem* item : textLabels ) {
-            item->setPos( scnRect.left(), item->y() );
+        Q_FOREACH( QGraphicsTextItem* item, textLabels ) {
+            item->setPos( scnRect.left()-textWidth, item->y() );
             item->show();
         }
-        if ( context.drawColumnLabels() ) {
-            labelsHeaderRect = sceneHeaderRect;
-            labelsHeaderRect.translate( -textWidth, 0.0 );
-            labelsHeaderRect.setWidth( textWidth );
-        }
-        labelsRect = QRectF( scnRect.left(), context.top(), textWidth, context.sceneRect().height() );
+        scnRect.setLeft( scnRect.left()-textWidth );
+        d->labelsWidth = textWidth;
     }
+
     setSceneRect( scnRect );
-    scnRect.setRight( context.right() );
 
-    // The scene looks like this:
-    //  Labels   Do not print    Print        Behind end
-    // 1       2               3            4
-    // !-------!---------------!------------!-----------
-    // sceneWidth is 1 to 2 + 3 to 4
-    qreal sceneWidth = d->labelsWidth + context.right() - context.left();
-    qreal sceneHeight = context.sceneRect().height() + sceneHeaderRect.height();
-    // qInfo()<<Q_FUNC_INFO<<targetRect<<scnRect<<sceneWidth;
-
-    int horPages = 1;
-    int vertPages = 1;
-    qreal scaleFactor = targetRect.height() / scnRect.height(); // FitPageHeight (default)
-    if ( printer ) {
-        if ( context.fitting() & PrintingContext::NoFitting ) {
-            scaleFactor = printer->logicalDpiX() / views().at(0)->logicalDpiX(); // always have only one view
-            vertPages = qRound( ( sceneHeight * scaleFactor / targetRect.height() ) + 0.5 );
-            horPages = qRound( ( sceneWidth * scaleFactor / targetRect.width() ) + 0.5 );
-        } else if ( context.fitting() & PrintingContext::FitSinglePage ) {
-            scaleFactor = std::min( scaleFactor, targetRect.width() / sceneWidth );
-        } else /*FitPageHeight (default)*/ {
-            horPages = qRound( ( sceneWidth * scaleFactor / targetRect.width() ) + 0.5 );
-        }
-    } else {
-        // paint device has no pages so just fit inside the target
-        scaleFactor = std::min( scaleFactor, targetRect.width() / sceneWidth );
-    }
-    // qInfo()<<Q_FUNC_INFO<<"labels header:"<<labelsHeaderRect<<"labels:"<<labelsRect<<"scene header:"<<sceneHeaderRect<<"scene:"<<scnRect<<"scaleFactor:"<<scaleFactor;
     painter->save();
-    painter->setFont( sceneFont );
+    painter->setClipRect( targetRect );
 
-    // qInfo()<<Q_FUNC_INFO<<'s'<<scaleFactor<<"pages="<<((sceneWidth * scaleFactor)/targetRect.width())<<'h'<<horPages<<'v'<<vertPages<<'s'<<scnRect<<'t'<<(targetRect.size()/scaleFactor);
-    qreal yPos = labelsRect.top();
-    for ( int vpage = 0; vpage < vertPages && yPos < context.bottom(); ++vpage ) {
-        // qInfo()<<Q_FUNC_INFO<<"print vertical page"<<vpage;
-        // Disable painting of noInformation during labels printing
-        // or else labels might be painted over
-        QBrush noInfoBrush;
-        DateTimeGrid *dateTimeGrid = qobject_cast<DateTimeGrid*>(grid());
-        if (dateTimeGrid) {
-            noInfoBrush = dateTimeGrid->noInformationBrush();
-            dateTimeGrid->setNoInformationBrush(QBrush());
-        }
-        int hpage = 0;
-        qreal targetLabelsOffset = 0.0;
-        qreal labelsOffsetX = 0.0;
-        while ( labelsOffsetX < labelsHeaderRect.width() ) {
-            // qInfo()<<Q_FUNC_INFO<<"print labels"<<"vert page:"<<vpage<<','<<hpage<<"yPos"<<yPos<<"label x:"<<labelsOffsetX;
-            // print labels, they might span multiple pages
-            QRectF target = targetRect;
-            target.setWidth(std::min(target.width(), (labelsHeaderRect.width() - labelsOffsetX) * scaleFactor) );
-            if ( vpage == 0 && headerHeight > 0.0 ) {
-                QRectF sourceHeader = labelsHeaderRect;
-                sourceHeader.translate( labelsOffsetX, 0.0 );
-                QRectF targetHeader = target;
-                targetHeader.setSize( sourceHeader.size() * scaleFactor );
-                drawLabelsHeader( painter, sourceHeader, targetHeader );
-                target.adjust( 0.0, targetHeader.height(), 0.0, 0.0 );
-            }
-            QRectF rect = labelsRect;
-            rect.setLeft( rect.left() + labelsOffsetX );
-            rect.setTop( yPos );
-            rect.setHeight( std::min(rect.height(), target.height() / scaleFactor ) );
-            painter->setClipRect(target);
-            // disable header, it has been drawn above
-            bool drawColumnLabels = d->drawColumnLabels;
-            d->drawColumnLabels = false;
-            // qInfo()<<Q_FUNC_INFO<<"print labels"<<"vert page:"<<vpage<<','<<hpage<<"scene rect:"<<rect<<"target:"<<target;
-            render( painter, target, rect );
-            d->drawColumnLabels = drawColumnLabels;
-            labelsOffsetX += rect.width();
-            if ( targetRect.right() <= target.right() ) {
-                // we have used the whole page
-                ++hpage;
-#ifdef HAVE_PRINTER
-                if ( printer ) {
-                    printer->newPage();
-                }
-#endif
-            } else {
-                // labels might take part of the page
-                targetLabelsOffset = target.width();
-                // qInfo()<<Q_FUNC_INFO<<"print labels finished"<<"vert page:"<<vpage<<"hor page:"<<hpage<<"target offset:"<<targetLabelsOffset;
-                break;
-            }
-        }
-        if (dateTimeGrid) {
-            dateTimeGrid->setNoInformationBrush(noInfoBrush);
-        }
-        qreal xPos = context.left();
-        // qInfo()<<Q_FUNC_INFO<<"print diagram"<<"page:"<<vpage<<','<<hpage<<"xPos"<<xPos<<"yPos:"<<yPos;
-        for ( ; hpage < horPages && xPos < context.right(); ++hpage ) {
-            // Adjust for row labels (first time only)
-            QRectF target = targetRect.adjusted(targetLabelsOffset, 0., 0., 0.);
-            targetLabelsOffset = 0.0;
-            if (!sceneHeaderRect.isNull() && vpage == 0) {
-                // draw header
-                QRectF rect = sceneHeaderRect;
-                rect.setLeft( xPos );
-                QRectF targetHeader = target;
-                targetHeader.setHeight( rect.height() * scaleFactor );
-                rect.setWidth( std::min( rect.width(), target.width() / scaleFactor) );
-                // qInfo()<<Q_FUNC_INFO<<"scene header:"<<"page:"<<vpage<<','<<hpage<<"source:"<<rect<<"target:"<<targetHeader;
-                render( painter, targetHeader, rect );
-                target.adjust( 0.0, targetHeader.height(), 0.0, 0.0 );
-            }
-            QRectF rect = context.sceneRect();
-            rect.setLeft( xPos );
-            rect.setTop( yPos );
-            rect.setWidth( std::min( rect.width(), target.width() / scaleFactor) );
-            rect.setHeight( std::min( rect.height(), target.height() / scaleFactor ) );
-            target.setWidth( rect.width() * scaleFactor );
-            painter->setClipRect( target );
-            // disable header, it has been drawn above
-            bool drawColumnLabels = d->drawColumnLabels;
-            d->drawColumnLabels = false;
-            // qInfo()<<Q_FUNC_INFO<<"scene:"<<"page:"<<vpage<<','<<hpage<<"source:"<<rect<<"target:"<<target;
-            render( painter, target, rect );
-            d->drawColumnLabels = drawColumnLabels;
+    qreal yratio = targetRect.height()/scnRect.height();
+    /* If we're not printing multiple pages,
+     * check if the span fits and adjust:
+     */
+    if ( !printer && targetRect.width()/scnRect.width() < yratio ) {
+        yratio = targetRect.width()/scnRect.width();
+    }
 
-            xPos += rect.width();
-            // qInfo()<<Q_FUNC_INFO<<context<<"xPos:"<<xPos;
-            if ( printer && xPos < context.right() ) {
+    qreal offset = scnRect.left();
+    int pagecount = 0;
+    while ( offset < scnRect.right() ) {
+        painter->setFont( sceneFont );
+        render( painter, targetRect, QRectF( QPointF( offset, scnRect.top()),
+                                             QSizeF( targetRect.width()/yratio, scnRect.height() ) ) );
+        offset += targetRect.width()/yratio;
+        ++pagecount;
+        if ( printer && offset < scnRect.right() ) {
 #ifdef HAVE_PRINTER
-                printer->newPage();
-#endif
-            } else {
-                // qInfo()<<Q_FUNC_INFO<<"print horizontal finished if"<<xPos<<">="<<scnRect.right();
-                break;
-            }
-        }
-        yPos += targetRect.height() / scaleFactor;
-        if ( vpage == 0 ) {
-            yPos -= headerHeight;
-        }
-        // qInfo()<<Q_FUNC_INFO<<"yPos:"<<yPos<<"bottom:"<<context.bottom();
-        if ( printer && yPos < context.bottom() ) {
-#ifdef HAVE_PRINTER
-            // next vertical page
             printer->newPage();
 #endif
+        } else {
+            break;
         }
-        // qInfo()<<Q_FUNC_INFO<<"next vertical page if"<<yPos<<'<'<<scnRect.bottom();
     }
 
     d->isPrinting = false;
@@ -1052,14 +842,6 @@ void GraphicsScene::doPrintScene( QPrinter *printer, QPainter *painter, const QR
     painter->restore();
 }
 
-void GraphicsScene::drawLabelsHeader( QPainter *painter, const QRectF &sourceRect, const QRectF &targetRect )
-{
-    // qInfo()<<Q_FUNC_INFO<<"header:"<<sourceRect<<targetRect;
-    // TODO This should paint itemview header
-    painter->setClipRect( targetRect );
-    render( painter, targetRect, sourceRect );
-}
-
 #include "moc_kganttgraphicsscene.cpp"
 
 
@@ -1087,30 +869,30 @@ public:
         m_model = model;
     }
 
-    /*reimp*/int headerHeight() const override { return 40; }
+    /*reimp*/int headerHeight() const Q_DECL_OVERRIDE { return 40; }
 
-    /*reimp*/ bool isRowVisible( const QModelIndex& ) const override { return true;}
-    /*reimp*/ bool isRowExpanded( const QModelIndex& ) const override { return false; }
-    /*reimp*/ KGantt::Span rowGeometry( const QModelIndex& idx ) const override
+    /*reimp*/ bool isRowVisible( const QModelIndex& ) const Q_DECL_OVERRIDE { return true;}
+    /*reimp*/ bool isRowExpanded( const QModelIndex& ) const Q_DECL_OVERRIDE { return false; }
+    /*reimp*/ KGantt::Span rowGeometry( const QModelIndex& idx ) const Q_DECL_OVERRIDE
     {
         return KGantt::Span( idx.row() * ROW_HEIGHT, ROW_HEIGHT );
     }
-    /*reimp*/ int maximumItemHeight() const override {
+    /*reimp*/ int maximumItemHeight() const Q_DECL_OVERRIDE {
         return ROW_HEIGHT/2;
     }
-    /*reimp*/int totalHeight() const override {
+    /*reimp*/int totalHeight() const Q_DECL_OVERRIDE {
         return m_model->rowCount()* ROW_HEIGHT;
     }
 
-    /*reimp*/ QModelIndex indexAt( int height ) const override {
+    /*reimp*/ QModelIndex indexAt( int height ) const Q_DECL_OVERRIDE {
         return m_model->index( height/ROW_HEIGHT, 0 );
     }
 
-    /*reimp*/ QModelIndex indexBelow( const QModelIndex& idx ) const override {
+    /*reimp*/ QModelIndex indexBelow( const QModelIndex& idx ) const Q_DECL_OVERRIDE {
         if ( !idx.isValid() )return QModelIndex();
         return idx.model()->index( idx.row()+1, idx.column(), idx.parent() );
     }
-    /*reimp*/ QModelIndex indexAbove( const QModelIndex& idx ) const override {
+    /*reimp*/ QModelIndex indexAbove( const QModelIndex& idx ) const Q_DECL_OVERRIDE {
         if ( !idx.isValid() )return QModelIndex();
         return idx.model()->index( idx.row()-1, idx.column(), idx.parent() );
     }
@@ -1140,14 +922,14 @@ KDAB_SCOPED_UNITTEST_SIMPLE( KGantt, GraphicsView, "test" ) {
     QStandardItem* item = new QStandardItem();
     item->setData( KGantt::TypeTask, KGantt::ItemTypeRole );
     item->setData( QString::fromLatin1( "Decide on new product" ) );
-    item->setData( QDateTime( QDate( 2007, 3, 1 ), QTime() ), KGantt::StartTimeRole );
-    item->setData( QDateTime( QDate( 2007, 3, 3 ), QTime() ), KGantt::EndTimeRole );
+    item->setData( QDateTime( QDate( 2007, 3, 1 ) ), KGantt::StartTimeRole );
+    item->setData( QDateTime( QDate( 2007, 3, 3 ) ), KGantt::EndTimeRole );
 
     QStandardItem* item2 = new QStandardItem();
     item2->setData( KGantt::TypeTask, KGantt::ItemTypeRole );
     item2->setData( QString::fromLatin1( "Educate personnel" ) );
-    item2->setData( QDateTime( QDate( 2007, 3, 3 ), QTime() ), KGantt::StartTimeRole );
-    item2->setData( QDateTime( QDate( 2007, 3, 6 ), QTime() ), KGantt::EndTimeRole );
+    item2->setData( QDateTime( QDate( 2007, 3, 3 ) ), KGantt::StartTimeRole );
+    item2->setData( QDateTime( QDate( 2007, 3, 6 ) ), KGantt::EndTimeRole );
 
     model.appendRow( item );
     model.appendRow( item2 );
