@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -25,7 +25,7 @@
 #include <QHash>
 
 namespace KGantt {
-    class ProxyModel::Private {
+    class Q_DECL_HIDDEN ProxyModel::Private {
     public:
         explicit Private( ProxyModel* _q );
 
