@@ -18,8 +18,6 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-#ifndef TESTGANTTCONSTRAINT_H
-#define TESTGANTTCONSTRAINT_H
 
 #include <QtTest>
 
@@ -33,4 +31,3 @@ private Q_SLOTS:
     void cleanupTestCase();
     void test();
 };
-#endif
