@@ -18,8 +18,6 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-#ifndef TESTKGANTTVIEW_H
-#define TESTKGANTTVIEW_H
 
 #include <QtTest>
 #include <QStandardItemModel>
@@ -55,9 +53,4 @@ private Q_SLOTS:
     void testListView();
 
     void testConstraints();
-
-    void testSetGraphicsView();
-
-    void testSetRowController();
 };
-#endif
